==> static-compat-qt6-quick3d-6.9.1-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Quick3DHelpers/Qt6Quick3DHelpersTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::Quick3DHelpers" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_MULTIPLICITY_RELEASE "3"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6Quick3DHelpers.a"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers "${_IMPORT_PREFIX}/lib/libQt6Quick3DHelpers.a" )

# Import target "Qt6::Quick3DHelpers_resources_1" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_Helpers_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_Helpers_init.cpp.o" )

# Import target "Qt6::Quick3DHelpers_resources_2" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_2/.qt/rcc/qrc_Quick3DHelpers_raw_qml_0_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_2/.qt/rcc/qrc_Quick3DHelpers_raw_qml_0_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> static-compat-qt6-quick3d-6.10.0-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Quick3DHelpers/Qt6Quick3DHelpersTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::Quick3DHelpers" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_MULTIPLICITY_RELEASE "3"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6Quick3DHelpers.a"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers "${_IMPORT_PREFIX}/lib/libQt6Quick3DHelpers.a" )

# Import target "Qt6::Quick3DHelpers_resources_1" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_Helpers_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_1/.qt/rcc/qrc_qmake_QtQuick3D_Helpers_init.cpp.o" )

# Import target "Qt6::Quick3DHelpers_resources_2" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_2/.qt/rcc/qrc_Quick3DHelpers_raw_qml_0_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_2/.qt/rcc/qrc_Quick3DHelpers_raw_qml_0_init.cpp.o" )

# Import target "Qt6::Quick3DHelpers_resources_3" for configuration "Release"
set_property(TARGET Qt6::Quick3DHelpers_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick3DHelpers_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_3/.qt/rcc/qrc_Quick3DHelpers_raw_res_0_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick3DHelpers_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick3DHelpers_resources_3 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick3D/Helpers/objects-Release/Quick3DHelpers_resources_3/.qt/rcc/qrc_Quick3DHelpers_raw_res_0_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
